@@ -2,13 +2,35 @@ import importlib.metadata
 
 __version__ = importlib.metadata.version("simple_downloader")
 
-import shutil
 from pathlib import Path
 from urllib.parse import urlparse
 
 import requests
 from pydantic import AnyHttpUrl, DirectoryPath, validate_arguments
-from tqdm.auto import tqdm
+
+# from tqdm.auto import tqdm
+from rich.progress import (
+    BarColumn,
+    DownloadColumn,
+    Progress,
+    TextColumn,
+    TimeRemainingColumn,
+    TransferSpeedColumn,
+)
+
+progress = Progress(
+    TextColumn("[bold]{task.fields[file_name]}", justify="right"),
+    BarColumn(bar_width=None),
+    "[progress.percentage]{task.percentage:>3.1f}%",
+    "|",
+    DownloadColumn(),
+    "|",
+    TransferSpeedColumn(),
+    "|",
+    TimeRemainingColumn(),
+    auto_refresh=True,
+    refresh_per_second=10,
+)
 
 
 @validate_arguments
@@ -26,9 +48,12 @@ def download(url: AnyHttpUrl, target_dir: DirectoryPath, force: bool = False) ->
 
     with requests.get(url, stream=True) as r:
         total_length = int(r.headers.get("Content-Length"))
-        with tqdm.wrapattr(
-            r.raw, "read", total=total_length, desc=f"Downloading {file_name}"
-        ) as raw:
-            with open(target_file, "wb") as output:
-                shutil.copyfileobj(raw, output)
+        with open(target_file, mode="wb") as output:
+            with progress:
+                t_id = progress.add_task(
+                    "Downloading...", total=total_length, file_name=file_name
+                )
+                for chunk in r.iter_content(chunk_size=1024):
+                    output.write(chunk)
+                    progress.update(t_id, advance=len(chunk))
     return target_file
